@@ -1,6 +1,7 @@
 from typing import List
 
-from ..datacube.datacube import Datacube
+from ..datacube.backends.datacube import Datacube
+from ..datacube.index_tree import IndexTree
 from ..shapes import ConvexPolytope
 
 
@@ -8,7 +9,7 @@ class Engine:
     def __init__(self):
         pass
 
-    def extract(self, datacube: Datacube, polytopes: List[ConvexPolytope]):
+    def extract(self, datacube: Datacube, polytopes: List[ConvexPolytope]) -> IndexTree:
         pass
 
     @staticmethod
